Index: trunk/psModules/src/config/pmConfigRecipes.c
===================================================================
--- trunk/psModules/src/config/pmConfigRecipes.c	(revision 15727)
+++ trunk/psModules/src/config/pmConfigRecipes.c	(revision 16611)
@@ -11,5 +11,5 @@
 #include "pmConfigRecipes.h"
 
-static bool loadRecipeSite(bool *status, pmConfig *config, psMetadata *source);
+static bool loadRecipeSystem(bool *status, pmConfig *config, psMetadata *source);
 static bool loadRecipeCamera(bool *status, pmConfig *config, psMetadata *source);
 static bool loadRecipeFromArguments(bool *status, pmConfig *config);
@@ -46,7 +46,7 @@
 
 // this function may be called several times.  it attempts to load the recipe data from one of
 // three locations: config->site, config->camera, and argv.  We cannot read the recipes
 // from config->camera until a camera has been read BUT, the argv recipes must override the
 // camera and site recipes.
 bool pmConfigReadRecipes(pmConfig *config, pmRecipeSource source)
 {
@@ -58,13 +58,13 @@
     }
 
-    // Read the recipe file names from the site configuration and camera configuration
-    // It is an error for config->site:recipes not to exist.  all programs install their
-    // master recipe files in the site:recipe location when they are built.
-    if (config->site && (source & PM_RECIPE_SOURCE_SITE)) {
-        if (!loadRecipeSite(&status, config, config->site)) {
-            psError(PS_ERR_IO, false, "Failed to read recipes from site config");
-            return false;
-        }
-        psTrace ("psModules.config", 3, "read recipes from site config");
+    // Read the recipe file names from the system configuration and camera configuration
+    // It is an error for config->complete:recipes not to exist.  all programs install their
+    // master recipe files in the system:recipe location when they are built.
+    if (config->complete && (source & PM_RECIPE_SOURCE_SYSTEM)) {
+        if (!loadRecipeSystem(&status, config, config->complete)) {
+            psError(PS_ERR_IO, false, "Failed to read recipes from system config");
+            return false;
+        }
+        psTrace ("psModules.config", 3, "read recipes from system config");
     }
 
@@ -283,6 +283,6 @@
 }
 
-// Load the recipe files for SITE : REQUIRED
-static bool loadRecipeSite(bool *status,
+// Load the recipe files for SYSTEM : REQUIRED
+static bool loadRecipeSystem(bool *status,
                            pmConfig *config, // The configuration into which to read the recipes
                            psMetadata *source // The source configuration, from which to read the filenames
@@ -294,6 +294,6 @@
 
     if (!source) {
-        psError(PS_ERR_IO, true, "The site configuration has not been read --- cannot read recipes from this location.\n");
-        config->recipesRead &= ~PM_RECIPE_SOURCE_SITE;
+        psError(PS_ERR_IO, true, "The system configuration has not been read --- cannot read recipes from this location.\n");
+        config->recipesRead &= ~PM_RECIPE_SOURCE_SYSTEM;
         return false;
     }
@@ -301,5 +301,5 @@
     psMetadata *recipes = psMetadataLookupMetadata(NULL, source, "RECIPES"); // The list of recipes
     if (!recipes) {
-        psError(PS_ERR_IO, false, "RECIPES not found in the site configuration\n");
+        psError(PS_ERR_IO, false, "RECIPES not found in the system configuration\n");
         return false;
     }
@@ -313,5 +313,5 @@
         // type mismatch is a serious error
         if (fileItem->type != PS_DATA_STRING) {
-            psError(PS_ERR_IO, true, "%s in site configuration RECIPES is not of type STR", fileItem->name);
+            psError(PS_ERR_IO, true, "%s in system configuration RECIPES is not of type STR", fileItem->name);
             return false;
         }
@@ -320,5 +320,5 @@
         psMetadata *recipe = NULL;
         if (!pmConfigFileRead(&recipe, fileItem->data.str, "recipe")) {
-            psError(PS_ERR_IO, false, "Failed to read recipe file %s listed in site configuration\n",
+            psError(PS_ERR_IO, false, "Failed to read recipe file %s listed in system configuration\n",
                     fileItem->data.str);
             return false;
@@ -331,5 +331,5 @@
     }
     psFree(recipesIter);
-    config->recipesRead |= PM_RECIPE_SOURCE_SITE;
+    config->recipesRead |= PM_RECIPE_SOURCE_SYSTEM;
 
     *status = true;
@@ -337,7 +337,7 @@
 }
 
 // Load the recipe files (valid for SITE | CAMERA)
 // each time we load a specific recipe, it overrides the existing metadata for that recipe
 // for sourceType == SITE | CAMERA, RECIPES contains a list of files to be read (pmConfigFileRead)
 static bool loadRecipeCamera(bool *status, // status variable
                              pmConfig *config, // The configuration into which to read the recipes
@@ -46,7 +46,7 @@
 
 // this function may be called several times.  it attempts to load the recipe data from one of
-// three locations: config->site, config->camera, and argv.  We cannot read the recipes
+// three locations: config->complete, config->camera, and argv.  We cannot read the recipes
 // from config->camera until a camera has been read BUT, the argv recipes must override the
@@ -46,7 +46,7 @@
 // from config->camera until a camera has been read BUT, the argv recipes must override the
-// camera and site recipes.
+// camera and system recipes.
 bool pmConfigReadRecipes(pmConfig *config, pmRecipeSource source)
 {
@@ -337,7 +337,7 @@
 }
 
-// Load the recipe files (valid for SITE | CAMERA)
+// Load the recipe files (valid for SYSTEM | CAMERA)
 // each time we load a specific recipe, it overrides the existing metadata for that recipe
@@ -337,7 +337,7 @@
 // each time we load a specific recipe, it overrides the existing metadata for that recipe
-// for sourceType == SITE | CAMERA, RECIPES contains a list of files to be read (pmConfigFileRead)
+// for sourceType == SYSTEM | CAMERA, RECIPES contains a list of files to be read (pmConfigFileRead)
 static bool loadRecipeCamera(bool *status, // status variable
                              pmConfig *config, // The configuration into which to read the recipes
